pub trait TraceApiClient<TxReq>: ClientT{
// Provided methods
fn trace_call(
&self,
call: TxReq,
trace_types: HashSet<TraceType>,
block_id: Option<BlockId>,
state_overrides: Option<StateOverride>,
block_overrides: Option<Box<BlockOverrides>>,
) -> impl Future<Output = Result<TraceResults, Error>> + Send { ... }
fn trace_call_many(
&self,
calls: Vec<(TxReq, HashSet<TraceType>)>,
block_id: Option<BlockId>,
) -> impl Future<Output = Result<Vec<TraceResults>, Error>> + Send { ... }
fn trace_raw_transaction(
&self,
data: Bytes,
trace_types: HashSet<TraceType>,
block_id: Option<BlockId>,
) -> impl Future<Output = Result<TraceResults, Error>> + Send { ... }
fn replay_block_transactions(
&self,
block_id: BlockId,
trace_types: HashSet<TraceType>,
) -> impl Future<Output = Result<Option<Vec<TraceResultsWithTransactionHash>>, Error>> + Send { ... }
fn replay_transaction(
&self,
transaction: B256,
trace_types: HashSet<TraceType>,
) -> impl Future<Output = Result<TraceResults, Error>> + Send { ... }
fn trace_block(
&self,
block_id: BlockId,
) -> impl Future<Output = Result<Option<Vec<LocalizedTransactionTrace>>, Error>> + Send { ... }
fn trace_filter(
&self,
filter: TraceFilter,
) -> impl Future<Output = Result<Vec<LocalizedTransactionTrace>, Error>> + Send { ... }
fn trace_get(
&self,
hash: B256,
indices: Vec<Index>,
) -> impl Future<Output = Result<Option<LocalizedTransactionTrace>, Error>> + Send { ... }
fn trace_transaction(
&self,
hash: B256,
) -> impl Future<Output = Result<Option<Vec<LocalizedTransactionTrace>>, Error>> + Send { ... }
fn trace_transaction_opcode_gas(
&self,
tx_hash: B256,
) -> impl Future<Output = Result<Option<TransactionOpcodeGas>, Error>> + Send { ... }
fn trace_block_opcode_gas(
&self,
block_id: BlockId,
) -> impl Future<Output = Result<Option<BlockOpcodeGas>, Error>> + Send { ... }
}client only.Expand description
Client implementation for the TraceApi RPC API.
Provided Methods
Sourcefn trace_call(
&self,
call: TxReq,
trace_types: HashSet<TraceType>,
block_id: Option<BlockId>,
state_overrides: Option<StateOverride>,
block_overrides: Option<Box<BlockOverrides>>,
) -> impl Future<Output = Result<TraceResults, Error>> + Send
fn trace_call( &self, call: TxReq, trace_types: HashSet<TraceType>, block_id: Option<BlockId>, state_overrides: Option<StateOverride>, block_overrides: Option<Box<BlockOverrides>>, ) -> impl Future<Output = Result<TraceResults, Error>> + Send
Executes the given call and returns a number of possible traces for it.
Sourcefn trace_call_many(
&self,
calls: Vec<(TxReq, HashSet<TraceType>)>,
block_id: Option<BlockId>,
) -> impl Future<Output = Result<Vec<TraceResults>, Error>> + Send
fn trace_call_many( &self, calls: Vec<(TxReq, HashSet<TraceType>)>, block_id: Option<BlockId>, ) -> impl Future<Output = Result<Vec<TraceResults>, Error>> + Send
Performs multiple call traces on top of the same block. i.e. transaction n will be executed on top of a pending block with all n-1 transactions applied (traced) first. Allows to trace dependent transactions.
Sourcefn trace_raw_transaction(
&self,
data: Bytes,
trace_types: HashSet<TraceType>,
block_id: Option<BlockId>,
) -> impl Future<Output = Result<TraceResults, Error>> + Send
fn trace_raw_transaction( &self, data: Bytes, trace_types: HashSet<TraceType>, block_id: Option<BlockId>, ) -> impl Future<Output = Result<TraceResults, Error>> + Send
Traces a call to eth_sendRawTransaction without making the call, returning the traces.
Expects a raw transaction data
Sourcefn replay_block_transactions(
&self,
block_id: BlockId,
trace_types: HashSet<TraceType>,
) -> impl Future<Output = Result<Option<Vec<TraceResultsWithTransactionHash>>, Error>> + Send
fn replay_block_transactions( &self, block_id: BlockId, trace_types: HashSet<TraceType>, ) -> impl Future<Output = Result<Option<Vec<TraceResultsWithTransactionHash>>, Error>> + Send
Replays all transactions in a block returning the requested traces for each transaction.
Sourcefn replay_transaction(
&self,
transaction: B256,
trace_types: HashSet<TraceType>,
) -> impl Future<Output = Result<TraceResults, Error>> + Send
fn replay_transaction( &self, transaction: B256, trace_types: HashSet<TraceType>, ) -> impl Future<Output = Result<TraceResults, Error>> + Send
Replays a transaction, returning the traces.
Sourcefn trace_block(
&self,
block_id: BlockId,
) -> impl Future<Output = Result<Option<Vec<LocalizedTransactionTrace>>, Error>> + Send
fn trace_block( &self, block_id: BlockId, ) -> impl Future<Output = Result<Option<Vec<LocalizedTransactionTrace>>, Error>> + Send
Returns traces created at given block.
Sourcefn trace_filter(
&self,
filter: TraceFilter,
) -> impl Future<Output = Result<Vec<LocalizedTransactionTrace>, Error>> + Send
fn trace_filter( &self, filter: TraceFilter, ) -> impl Future<Output = Result<Vec<LocalizedTransactionTrace>, Error>> + Send
Returns traces matching given filter.
This is similar to eth_getLogs but for traces.
Sourcefn trace_get(
&self,
hash: B256,
indices: Vec<Index>,
) -> impl Future<Output = Result<Option<LocalizedTransactionTrace>, Error>> + Send
fn trace_get( &self, hash: B256, indices: Vec<Index>, ) -> impl Future<Output = Result<Option<LocalizedTransactionTrace>, Error>> + Send
Returns transaction trace at given index.
indices represent the index positions of the traces.
Note: This expects a list of indices but only one is supported since this function returns a
single [LocalizedTransactionTrace].
Sourcefn trace_transaction(
&self,
hash: B256,
) -> impl Future<Output = Result<Option<Vec<LocalizedTransactionTrace>>, Error>> + Send
fn trace_transaction( &self, hash: B256, ) -> impl Future<Output = Result<Option<Vec<LocalizedTransactionTrace>>, Error>> + Send
Returns all traces of given transaction.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".