pub trait TestingApiServer:
Sized
+ Send
+ Sync
+ 'static {
// Required methods
fn build_block_v1<'life0, 'async_trait>(
&'life0 self,
request: TestingBuildBlockRequestV1,
) -> Pin<Box<dyn Future<Output = RpcResult<ExecutionPayloadEnvelopeV5>> + Send + 'async_trait>>
where Self: 'async_trait,
'life0: 'async_trait;
fn commit_block_v1<'life0, 'async_trait>(
&'life0 self,
payload_attributes: PayloadAttributes,
transactions: Option<Vec<Bytes>>,
extra_data: Option<Bytes>,
) -> Pin<Box<dyn Future<Output = RpcResult<B256>> + Send + 'async_trait>>
where Self: 'async_trait,
'life0: 'async_trait;
// Provided method
fn into_rpc(self) -> RpcModule<Self> { ... }
}Expand description
Server trait implementation for the TestingApi RPC API.
Required Methods
Sourcefn build_block_v1<'life0, 'async_trait>(
&'life0 self,
request: TestingBuildBlockRequestV1,
) -> Pin<Box<dyn Future<Output = RpcResult<ExecutionPayloadEnvelopeV5>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
fn build_block_v1<'life0, 'async_trait>(
&'life0 self,
request: TestingBuildBlockRequestV1,
) -> Pin<Box<dyn Future<Output = RpcResult<ExecutionPayloadEnvelopeV5>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
Builds a block using the provided parent, payload attributes, and transactions.
See https://github.com/marcindsobczak/execution-apis/blob/main/src/testing/testing_buildBlockV1.md
Sourcefn commit_block_v1<'life0, 'async_trait>(
&'life0 self,
payload_attributes: PayloadAttributes,
transactions: Option<Vec<Bytes>>,
extra_data: Option<Bytes>,
) -> Pin<Box<dyn Future<Output = RpcResult<B256>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
fn commit_block_v1<'life0, 'async_trait>(
&'life0 self,
payload_attributes: PayloadAttributes,
transactions: Option<Vec<Bytes>>,
extra_data: Option<Bytes>,
) -> Pin<Box<dyn Future<Output = RpcResult<B256>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
Builds a block on top of the current canonical head, inserts it, and makes it canonical.
Provided Methods
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".